/**
 * @license
 * Copyright 2022 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */

import { createRequire } from 'node:module';
import path from 'node:path';
import url from 'node:url';

import type { JSONSchema8 as Schema } from 'jsonschema8';
import { glob } from 'glob';

const dirname = path.dirname(url.fileURLToPath(import.meta.url));

const schemas = await glob('*.schema.{c,m,}js', {
  cwd: dirname,
  posix: true,
  dotRelative: true,
  matchBase: true,
});

/**
 * Every .schema.ts file we have
 */
export const keys = schemas.map((key) =>
  key.replace(/\/+/, '/').replace(/\.[cm]?[jt]s$/, '.json'),
);

export const requireSchema: (path: string) => Schema = createRequire(
  path.join(dirname, 'schemas'),
);
export interface SchemaInfo {
  readonly key: string;
  readonly path: string;
  readonly schema: Schema;
}

/**
 * Load all the schemas
 */
async function* loadAllFormats(): Generator<SchemaInfo, void, void> {
  for await (const s of schemas) {
    const schema = (await import(s)) as Schema;
    const key = s.replace(/\.[cm]?[jt]s$/, '.json');
    yield {
      key,
      path: path.join(dirname, key),
      schema,
    };
  }
}

export default loadAllFormats;
