/**
 * @license
 * Copyright 2023 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */
import type { JSONSchema8 as Schema } from 'jsonschema8';

import { rfc } from '@oada/schemas/utils';

const _foo = rfc`12234${1}`;

const schema: Schema = {
  $id: 'https://formats.openag.io/jose/jwa.schema.json',
  $schema: 'http://json-schema.org/draft-07/schema#',
  title: 'JWA',
  description:
    '@see {@link https://datatracker.ietf.org/doc/html/rfc7518 JSON Web Algorithms (JWA)}',
  definitions: {
    kty: {
      title: 'kty (Key Type) parameter',
      description:
        'Identifies the cryptographic algorithm family used with the key',
      examples: ['RSA', 'EC'],
      oneOf: [
        { $ref: '#/definitions/registered/definitions/kty' },
        { type: 'string' },
      ],
    },
    alg: { type: 'string' },
    registered: {
      definitions: {
        kty: {
          title: 'Registered kty',
          oneOf: [
            {
              title: 'EC',
              description: 'Elliptic Curve\n@see {@link rfc:7518}',
              const: 'EC',
            },
            { title: 'RSA', description: 'RSA', const: 'RSA' },
            { title: 'oct', description: 'Octet sequence', const: 'oct' },
            {
              title: 'OKP',
              description: 'Octet string key pairs',
              const: 'OKP',
            },
          ],
        },
      },
    },
  },
};

export = schema;
