/**
 * @license
 * Copyright 2023 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */
import type { JSONSchema8 as Schema } from 'jsonschema8';

import { ianaAssignments, rfc } from '@oada/schemas/utils';

const ktys = await ianaAssignments('jose', 'web-key-types');

export default {
  $id: 'https://formats.openag.io/jose/jwa.schema.json',
  $schema: 'http://json-schema.org/draft-07/schema#',
  title: 'JWA',
  description: `@see {@link ${rfc(7518)} JSON Web Algorithms (JWA)}`,
  definitions: {
    kty: {
      title: 'kty (Key Type) parameter',
      description:
        'Identifies the cryptographic algorithm family used with the key',
      examples: ['RSA', 'EC'],
      // eslint-disable-next-line unicorn/no-useless-spread
      ...{ tsType: 'TypeFest.LiteralUnion<RegisteredKty, string>' },
      oneOf: [
        { $ref: '#/definitions/registered/definitions/kty' },
        { type: 'string' },
      ],
    },
    alg: { type: 'string' },
    registered: {
      definitions: {
        kty: {
          title: 'Registered kty',
          oneOf: await ktys.map((kty) => ({
            title: kty.name,
            description: `${kty.description}\n@see {@link ${kty.reference}}`,
            const: kty.name,
          })),
        },
      },
    },
  },
} as const satisfies Schema;
