/**
 * @license
 * Copyright 2023 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */
import type { JSONSchema8 as Schema } from 'jsonschema8';

import { ianaAssignments, rfc } from '@oada/schemas/utils';

const algs = await ianaAssignments(
  'jose',
  'web-signature-encryption-algorithms',
);
const ktys = await ianaAssignments('jose', 'web-key-types');

export default {
  $id: 'https://formats.openag.io/jose/jwa.schema.json',
  $schema: 'http://json-schema.org/draft-07/schema#',
  title: 'JWA',
  description: `@see {@link ${rfc(7518)} JSON Web Algorithms (JWA)}`,
  definitions: {
    kty: {
      title: 'kty (Key Type) parameter',
      description:
        'Identifies the cryptographic algorithm family used with the key',
      definitions: {
        registered: {
          title: 'Registered kty',
          description: `IANA registered values for kty parameter\n@see {@link ${ktys.uri}}`,
          oneOf: await ktys.map((kty) => ({
            title: kty.name,
            description: `${kty.description}\n@see {@link ${kty.reference}}`,
            const: kty.name,
          })),
        },
      },
      oneOf: [
        { $ref: '#/definitions/kty/definitions/registered' },
        { $ref: '../utils.schema.json#/definitions/anyOtherString' },
      ],
    },
    alg: {
      title: 'alg (Algorithm) parameter',
      description: '',
      definitions: {
        registered: {
          title: 'Registered alg',
          description: `IANA registered values for alg parameter\n@see {@link ${algs.uri}}`,
          oneOf: await algs.map((alg) => ({
            title: alg.name,
            description: `${alg.description}\n@see {@link ${alg.reference}}`,
            const: alg.name,
          })),
        },
      },
    },
  },
} as const satisfies Schema;
