/**
 * @license
 * Copyright 2023 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */

/**
 * RFC 7517
 * @see {@link https://datatracker.ietf.org/doc/html/rfc7517}
 */

import type { JSONSchema8 as Schema } from 'jsonschema8';

import { rfc } from '@oada/schemas/utils';

const schema = {
  $id: 'https://formats.openag.io/jose/jwk.schema.json',
  $schema: 'http://json-schema.org/draft-07/schema#',
  title: 'JWK',
  description: `@see {@link ${rfc(7517, 4)} JSON Web Key (JWK)}`,
  definitions: {
    jwk: {
      type: 'object',
      required: ['kty'],
      properties: {
        kty: { $ref: './jwa.schema.json#/definitions/kty' },
        use: { $ref: '#/definitions/parameters/definitions/use' },
        key_ops: { $ref: '#/definitions/parameters/definitions/key_ops' },
        alg: { $ref: './jwa.schema.json#/definitions/alg' },
      },
    },
    jwks: {
      type: 'object',
      required: ['keys'],
      properties: {
        keys: { type: 'array', items: { $ref: '#/definitions/jwk' } },
      },
    },
    parameters: {
      definitions: {
        'use': { type: 'string' },
        'key_ops': { type: 'string' },
        'kid': { type: 'string' },
        'x5u': { type: 'string', format: 'uri' },
        'x5c': { type: 'array', items: { type: 'string', format: 'base64' } },
        'x5t': { type: 'string', format: 'base64url' },
        'x5t#S256': { type: 'string', format: 'base64url' },
      },
    },
  },
  oneOf: [{ $ref: '#/definitions/jwk' }],
} as const satisfies Schema;

export = schema;
