/**
 * @license
 * Copyright 2022 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */

import type { JSONSchema8 as Schema } from 'jsonschema8';

// HACK to estimate regex `^[^_]` in TypeScript
const chars: string[] = [];
for (let c = 'a'; c <= 'z'; c = String.fromCodePoint(c.codePointAt(0)! + 1)) {
  chars.push(c);
}

const schema: Schema = {
  $id: 'https://formats.openag.io/oada/service/jobs.schema.json',
  $schema: 'http://json-schema.org/draft-07/schema#',
  description: 'The format for @oada/jobs jobs list',
  definitions: {
    letter: {
      description: 'A letter in the alphabet',
      enum: chars,
    },
    nonOadaKey: {
      title: 'non OADA key',
      type: 'string',
      pattern: '^[^_]',
      // eslint-disable-next-line unicorn/no-useless-spread
      ...{
        // eslint-disable-next-line no-template-curly-in-string
        tsType: '`${Letter | number | Uppercase<Letter>}${string}`',
      },
    },
  },
  type: 'object',
  allOf: [
    {
      $ref: '../resource.schema.json',
    },
  ],
  // eslint-disable-next-line unicorn/no-useless-spread
  ...{
    tsType: `I; export interface I extends OADAResource { [key: NonOADAKey]: {_id: string}; }`,
  },
  patternProperties: {
    '^[^_]': {
      type: 'object',
      properties: {
        _id: {
          $ref: '../../oada.schema.json#/definitions/_id',
        },
      },
      required: ['_id'],
    },
  },
  examples: [
    {
      _id: 'resources/123',
      _rev: 3,
      _meta: {
        _id: 'resources/123/_meta',
        _rev: 3,
      },
      _type: 'application/vnd.oada.service.jobs.1+json',
      asdxjkacsdj: {
        _id: 'resources/ajajkjfsdaf',
        _rev: 1,
      },
    },
  ],
};

export = schema;
