/**
 * @license
 * Copyright 2022 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */

import { $ref, patternProperty, typescript } from '@oada/schemas/utils';

import type { JSONSchema8 as Schema } from 'jsonschema8';

import oadaSchema from '../../oada.schema.cjs';

// HACK to estimate regex `^[^_]` in TypeScript
const chars: string[] = [];
for (let c = 'a'; c <= 'z'; c = String.fromCodePoint(c.codePointAt(0)! + 1)) {
  chars.push(c);
}

const r = $ref(oadaSchema, '/definitions/_type');
const foo = `${r}` as const;

const treeKey = {
  title: 'Tree key',
  type: 'string',
  pattern: '^[^_]',
  ...typescript`'*' | \`\${Letter | Uppercase<Letter>}\${string}\``,
} as const satisfies Schema;

const schema = {
  $id: 'https://formats.openag.io/oada/tree/v1.schema.json',
  $schema: 'http://json-schema.org/draft-07/schema#',
  title: 'Tree',
  description: 'An object representation of an OADA "tree".',
  definitions: {
    letter: {
      description: 'A letter in the alphabet',
      enum: chars,
    },
    treeKey,
  },
  type: 'object',
  properties: {
    _type: {
      $ref: '../../oada.schema.json#/definitions/_type',
    },
    _rev: {
      $ref: '../../oada.schema.json#/definitions/_rev',
    },
  },
  allOf: [
    {
      description: 'sub trees',
      type: 'object',
      ...typescript`{ [key in ${treeKey}]: Tree; }`,
      patternProperties: {
        [`${r}`]: {},
        [patternProperty(treeKey)]: {
          $ref: '#',
        },
      },
    },
  ],
} as const satisfies Schema;

export = schema;
