/**
 * @license
 * Copyright 2023 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */

/**
 * @see {@link https://datatracker.ietf.org/doc/html/rfc7517}
 */

import type { JSONSchema8 as Schema } from 'jsonschema8';

const schema: Schema = {
  $id: 'https://formats.openag.io/rfc/7517.schema.json',
  $schema: 'http://json-schema.org/draft-07/schema#',
  title: 'JWK',
  description:
    '@see {@link https://datatracker.ietf.org/doc/html/rfc7517#section-4 JSON Web Key (JWK)}',
  definitions: {
    'jwk': {
      type: 'object',
      required: ['kty'],
      properties: {
        kty: { $ref: '#/definitions/kty' },
        use: { $ref: '#/definitions/use' },
        key_ops: { $ref: '#/definitions/key_ops' },
      },
    },
    'jwks': { type: 'object', required: ['keys'], properties: { keys: {type: 'array', items: {"#/definitions/jwk"}} } },
    'kty': {
      title: 'kty (Key Type) parameter',
      description:
        'Identifies the cryptographic algorithm family used with the key',
      examples: ['RSA', 'EC'],
      type: 'string',
    },
    'use': { type: 'string' },
    'key_ops': { type: 'string' },
    'alg': { type: 'string' },
    'kid': { type: 'string' },
    'x5u': { type: 'string', format: 'uri' },
    'x5c': { type: 'array', items: { type: 'string', format: 'base64' } },
    'x5t': { type: 'string', format: 'base64url' },
    'x5t#S256': { type: 'string', format: 'base64url' },
  },
};

export = schema;
