declare const _default: {
    readonly $id: "https://formats.openag.io/jose/jwa.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly title: "JWA";
    readonly description: "@see {@link https://datatracker.ietf.org/doc/html/rfc7518 JSON Web Algorithms (JWA)}";
    readonly definitions: {
        readonly alg: {
            readonly title: "alg (Algorithm) parameter";
            readonly description: "JSON Web Signature and Encryption Algorithms";
            readonly definitions: {
                readonly registered: {
                    readonly title: "Registered alg";
                    readonly description: "IANA registered values for JSON Web Signature and Encryption Algorithms\n@see {@link https://www.iana.org/assignments/jose/jose.xhtml#web-signature-encryption-algorithms}";
                    readonly $comment: `Enum retrieved dynamically from https://www.iana.org/assignments/jose/jose.xhtml#web-signature-encryption-algorithms on ${string}`;
                    readonly oneOf: {
                        title: string;
                        description: string;
                        const: string;
                    }[];
                };
            };
            readonly oneOf: readonly [{
                readonly $ref: "#/definitions/alg/definitions/registered";
            }, {
                readonly $ref: "../utils.schema.json#/definitions/anyOtherString";
            }];
        };
        readonly kty: {
            readonly title: "kty (Key Type) parameter";
            readonly description: "Identifies the cryptographic algorithm family used with the key";
            readonly definitions: {
                readonly registered: {
                    readonly title: "Registered kty";
                    readonly description: "IANA registered values for JSON Web Key Types\n@see {@link https://www.iana.org/assignments/jose/jose.xhtml#web-key-types}";
                    readonly $comment: `Enum retrieved dynamically from https://www.iana.org/assignments/jose/jose.xhtml#web-key-types on ${string}`;
                    readonly oneOf: {
                        title: string;
                        description: string;
                        const: string;
                    }[];
                };
            };
            readonly oneOf: readonly [{
                readonly $ref: "#/definitions/kty/definitions/registered";
            }, {
                readonly $ref: "../utils.schema.json#/definitions/anyOtherString";
            }];
        };
        readonly zip: {
            readonly title: "zip (Compression Algorithm) parameter";
            readonly description: "JSON Web Encryption Compression Algorithms";
            readonly definitions: {
                readonly registered: {
                    readonly title: "Registered zip";
                    readonly description: "IANA registered values for JSON Web Encryption Compression Algorithms\n@see {@link https://www.iana.org/assignments/jose/jose.xhtml#web-encryption-compression-algorithms}";
                    readonly $comment: `Enum retrieved dynamically from https://www.iana.org/assignments/jose/jose.xhtml#web-encryption-compression-algorithms on ${string}`;
                    readonly oneOf: {
                        title: string;
                        description: string;
                        const: string;
                    }[];
                };
            };
            readonly oneOf: readonly [{
                readonly $ref: "#/definitions/zip/definitions/registered";
            }, {
                readonly $ref: "../utils.schema.json#/definitions/anyOtherString";
            }];
        };
        readonly crv: {
            readonly title: "crv (Curve) parameter";
            readonly description: "JSON Web Key Elliptic Curve";
            readonly definitions: {
                readonly registered: {
                    readonly title: "Registered crv";
                    readonly description: "IANA registered values for JSON Web Key Elliptic Curve\n@see {@link https://www.iana.org/assignments/jose/jose.xhtml#web-key-elliptic-curve}";
                    readonly $comment: `Enum retrieved dynamically from https://www.iana.org/assignments/jose/jose.xhtml#web-key-elliptic-curve on ${string}`;
                    readonly oneOf: {
                        title: string;
                        description: string;
                        const: string;
                    }[];
                };
            };
            readonly oneOf: readonly [{
                readonly $ref: "#/definitions/crv/definitions/registered";
            }, {
                readonly $ref: "../utils.schema.json#/definitions/anyOtherString";
            }];
        };
    };
};
export default _default;
