declare const _default: {
    readonly $id: "https://formats.openag.io/jose/jwk.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly title: "JWK";
    readonly description: "@see {@link https://datatracker.ietf.org/doc/html/rfc7517 JSON Web Key (JWK)}";
    readonly definitions: {
        readonly jwk: {
            readonly properties: {
                [x: string & Record<never, never>]: {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                };
                kty: {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                    allOf: {
                        $ref: string;
                    }[];
                };
                use: {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                    allOf: {
                        $ref: string;
                    }[];
                };
                key_ops: {
                    readonly title: string;
                    type: string;
                    uniqueItems: boolean;
                    items: {
                        $ref: string;
                    };
                    description: string;
                };
                alg: {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                    allOf: {
                        $ref: string;
                    }[];
                };
                kid: {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                    type: string;
                };
                x5u: {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                    type: string;
                    format: string;
                };
                x5c: {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                    type: string;
                    minItems: number;
                    items: {
                        type: string;
                        contentEncoding: string;
                        contentMediaType: string;
                    };
                };
                x5t: {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                    type: string;
                    contentEncoding: string;
                };
                'x5t#S256': {
                    readonly title: string;
                    readonly description: `${string}\n@see {@link ${string}}`;
                    type: string;
                    contentEncoding: string;
                };
            };
            readonly description: "@see {@link https://datatracker.ietf.org/doc/html/rfc7517#section-4 JSON Web Key (JWK) Format}";
            readonly type: "object";
            readonly required: readonly ["kty"];
        };
        readonly jwks: {
            readonly type: "object";
            readonly required: readonly ["keys"];
            readonly properties: {
                readonly keys: {
                    readonly type: "array";
                    readonly items: {
                        readonly $ref: "#/definitions/jwk";
                    };
                };
            };
        };
        readonly use: {
            readonly oneOf: readonly [{
                readonly $ref: "#/definitions/use/definitions/registered";
            }, {
                readonly $ref: "../utils.schema.json#/definitions/anyOtherString";
            }];
            readonly definitions: {
                readonly registered: {
                    readonly $comment: `Enum retrieved dynamically from https://www.iana.org/assignments/jose/jose.xhtml#web-key-use on ${string}`;
                    readonly oneOf: {
                        title: string;
                        description: `${string}\n@see {@link ${string}}`;
                        const: string;
                    }[];
                };
            };
        };
        readonly key_op: {
            readonly oneOf: readonly [{
                readonly $ref: "#/definitions/key_op/definitions/registered";
            }, {
                readonly $ref: "../utils.schema.json#/definitions/anyOtherString";
            }];
            readonly definitions: {
                readonly registered: {
                    readonly $comment: `Enum retrieved dynamically from https://www.iana.org/assignments/jose/jose.xhtml#web-key-operations on ${string}`;
                    readonly oneOf: {
                        title: string;
                        description: `${string}\n@see {@link ${string}}`;
                        const: string;
                    }[];
                };
            };
        };
    };
    readonly oneOf: readonly [{
        readonly $ref: "#/definitions/jwk";
    }];
    readonly examples: readonly [{
        readonly kty: "EC";
        readonly crv: "P-256";
        readonly x: "f83OJ3D2xF1Bg8vub9tLe1gHMzV76e8Tus9uPHvRVEU";
        readonly y: "x_FEzRu9m36HLN_tue659LNpXW6pCyStikYjKIWI5a0";
        readonly kid: "Public key used in JWS spec Appendix A.3 example";
    }];
};
export default _default;
