declare const schema: {
    readonly $id: "https://formats.openag.io/modus/v1/modus-result.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Modus document for submission of lab results to FMIS";
    readonly $comment: "The main lab result format for Modus V1, converted from the XSD";
    readonly type: "object";
    readonly properties: {
        readonly _type: {
            readonly $comment: "content type for API responses";
            readonly const: "application/vnd.modus.v1.modus-result+json";
        };
        readonly Events: {
            readonly type: "array";
            readonly items: {
                readonly $comment: "this is an \"Event\"";
                readonly type: "object";
                readonly properties: {
                    readonly EventMetaData: {
                        readonly type: "object";
                        readonly properties: {
                            readonly EventCode: {
                                readonly description: "Unique human readable code for the sample event. Often referred to a Layer ID";
                                readonly type: "string";
                            };
                            readonly EventType: {
                                readonly $ref: "./global.schema.json#/$defs/EventType";
                            };
                            readonly EventExpirationDate: {
                                readonly type: "string";
                                readonly format: "date";
                                readonly description: "The date the data in event is to expire for use in a recommendation";
                            };
                        };
                    };
                    readonly LabMetaData: {
                        readonly $ref: "./global.schema.json#/$defs/LabMetaData";
                    };
                    readonly FMISMetadata: {
                        readonly $ref: "./global.schema.json#/$defs/FMISMetadata";
                    };
                    readonly EventSamples: {
                        readonly description: "Element contains the field sample points and data";
                        readonly type: "object";
                        readonly properties: {
                            readonly Soil: {
                                readonly description: "Element to place samples and results from a soil sample event";
                                readonly type: "object";
                                readonly properties: {
                                    readonly DepthRefs: {
                                        readonly $ref: "./global.schema.json#/$defs/DepthRefs";
                                    };
                                    readonly RecommendationRefs: {
                                        readonly $ref: "./global.schema.json#/$defs/RecommendationRefs";
                                    };
                                    readonly SoilSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly $comment: "A \"SoilSample\"";
                                            readonly description: "Element that contains the soil sample event data under the soil event";
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly Depths: {
                                                    readonly description: "A container for the different depths being reported";
                                                    readonly type: "array";
                                                    readonly items: {
                                                        readonly description: "Container for results at a defined depth. The Depth ID is defined in DepthRefs";
                                                        readonly type: "object";
                                                        readonly properties: {
                                                            readonly NutrientResults: {
                                                                readonly $ref: "./global.schema.json#/$defs/NutrientResults";
                                                            };
                                                            readonly TextureResults: {
                                                                readonly $ref: "./global.schema.json#/$defs/TextureResults";
                                                            };
                                                            readonly DepthID: {
                                                                readonly description: "Depth ID from the Depth Reference";
                                                                readonly type: readonly ["number", "string"];
                                                            };
                                                        };
                                                    };
                                                };
                                                readonly NutrientRecommendations: {
                                                    readonly $ref: "./global.schema.json#/$defs/NutrientRecommendations";
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                            readonly Plant: {
                                readonly description: "Element to place samples and results from a plant tissue sample event";
                                readonly type: "object";
                                readonly properties: {
                                    readonly RecommendationRefs: {
                                        readonly $ref: "./global.schema.json#/$defs/RecommendationRefs";
                                    };
                                    readonly PlantSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly NutrientResults: {
                                                    readonly $ref: "./global.schema.json#/$defs/NutrientResults";
                                                };
                                                readonly NutrientRecommendations: {
                                                    readonly $ref: "./global.schema.json#/$defs/NutrientRecommendations";
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                            readonly Nematode: {
                                readonly description: "Element to place samples and results from a nematode sample event";
                                readonly type: "object";
                                readonly properties: {
                                    readonly DepthRefs: {
                                        readonly $ref: "./global.schema.json#/$defs/DepthRefs";
                                    };
                                    readonly NematodeSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly Depths: {
                                                    readonly type: "array";
                                                    readonly items: {
                                                        readonly type: "object";
                                                        readonly properties: {
                                                            readonly NematodeResults: {
                                                                readonly $ref: "./global.schema.json#/$defs/NematodeResults";
                                                            };
                                                            readonly DepthID: {
                                                                readonly type: "integer";
                                                                readonly minimum: 1;
                                                            };
                                                        };
                                                    };
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                            readonly Water: {
                                readonly type: "object";
                                readonly properties: {
                                    readonly WaterSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly Source: {
                                                    readonly type: "string";
                                                };
                                                readonly NutrientResults: {
                                                    readonly $ref: "./global.schema.json#/$defs/NutrientResults";
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                            readonly Residue: {
                                readonly type: "object";
                                readonly properties: {
                                    readonly ResidueSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly ResidueResults: {
                                                    readonly $ref: "./global.schema.json#/$defs/ResidueResults";
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                        };
                    };
                    readonly Comments: {
                        readonly $ref: "./global.schema.json#/$defs/Comments";
                    };
                    readonly ModusSubmit: {
                        readonly $comment: "can hold an entire ModusSubmit document?";
                        readonly $ref: "./modus-submit.schema.json";
                    };
                };
            };
        };
        readonly Version: {
            readonly type: "string";
            readonly default: "1.0";
        };
    };
    readonly examples: readonly [{
        readonly _type: "application/vnd.modus.v1.modus-result+json";
        readonly ModusResult: {
            readonly Events: readonly [{
                readonly EventMetaData: {
                    readonly EventCode: "ece3a2a8-4340-48b1-ae1f-d48d1f1e1692";
                    readonly EventDate: "2021-09-24";
                    readonly EventType: {
                        readonly Soil: true;
                    };
                };
                readonly LabMetaData: {
                    readonly LabName: "A & L Great Lakes Laboratories";
                    readonly LabEventID: "F21267-0039";
                    readonly Contact: {
                        readonly Name: "A & L Great Lakes Laboratories";
                        readonly Phone: "260.483.4759";
                        readonly Address: "3505 Conestoga Dr.\nFort Wayne, IN 46808";
                    };
                    readonly ReceivedDate: "2021-09-24T00:00:00.000";
                    readonly ProcessedDate: "2021-09-28T00:00:00.000";
                    readonly ClientAccount: {
                        readonly AccountNumber: "30039";
                        readonly Company: "THE ANDERSONS FARM CTR - GPS";
                        readonly City: "N MANCHESTER";
                        readonly State: "IN";
                    };
                    readonly Reports: {
                        readonly '1': {
                            readonly LabReportID: "F21271-0035";
                        };
                    };
                };
                readonly FMISMetaData: {
                    readonly FMISEventID: "ece3a2a8-4340-48b1-ae1f-d48d1f1e1692";
                    readonly FMISProfile: {
                        readonly Grower: "CARL AULT";
                        readonly Farm: "ENYART EAST 50";
                        readonly Field: "50.1 AC";
                        readonly 'Sub-Field': "";
                    };
                };
                readonly EventSamples: {
                    readonly Soil: {
                        readonly DepthRefs: {
                            readonly '1': {
                                readonly Name: "Unknown Depth";
                                readonly StartingDepth: 0;
                                readonly EndingDepth: 8;
                                readonly ColumnDepth: 8;
                                readonly DepthUnit: "in";
                            };
                        };
                        readonly SoilSamples: readonly [{
                            readonly SampleMetaData: {
                                readonly SampleNumber: 1;
                                readonly ReportID: 28051;
                            };
                            readonly Depths: readonly [{
                                readonly DepthID: "1";
                                readonly NutrientResults: {
                                    readonly pH: {
                                        readonly Value: 7;
                                        readonly ValueUnit: "none";
                                    };
                                    readonly OM: {
                                        readonly Value: 2.4;
                                        readonly ValueUnit: "%";
                                    };
                                    readonly P: {
                                        readonly Value: 34;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly K: {
                                        readonly Value: 161;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly Ca: {
                                        readonly Value: 1150;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly Mg: {
                                        readonly Value: 240;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly CEC: {
                                        readonly Value: 8.2;
                                        readonly ValueUnit: "meq/100g";
                                    };
                                    readonly 'BS-Ca': {
                                        readonly Value: 70.4;
                                        readonly ValueUnit: "%";
                                    };
                                    readonly 'BS-Mg': {
                                        readonly Value: 24.5;
                                        readonly ValueUnit: "%";
                                    };
                                    readonly 'BS-K': {
                                        readonly Value: 5.1;
                                        readonly ValueUnit: "%";
                                    };
                                    readonly 'SO4-S': {
                                        readonly Value: 7;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly Zn: {
                                        readonly Value: 3.3;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly Mn: {
                                        readonly Value: 46;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly B: {
                                        readonly Value: 0.7;
                                        readonly ValueUnit: "ppm";
                                    };
                                };
                            }];
                        }, {
                            readonly SampleMetaData: {
                                readonly SampleNumber: 2;
                                readonly ReportID: 28052;
                            };
                            readonly Depths: readonly [{
                                readonly DepthID: "1";
                                readonly NutrientResults: {
                                    readonly pH: {
                                        readonly Value: 7.6;
                                        readonly ValueUnit: "none";
                                    };
                                    readonly OM: {
                                        readonly Value: 2.7;
                                        readonly ValueUnit: "%";
                                    };
                                    readonly P: {
                                        readonly Value: 30;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly K: {
                                        readonly Value: 190;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly Ca: {
                                        readonly Value: 1950;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly Mg: {
                                        readonly Value: 265;
                                        readonly ValueUnit: "ppm";
                                    };
                                    readonly CEC: {
                                        readonly Value: 12.4;
                                        readonly ValueUnit: "meq/100g";
                                    };
                                    readonly 'BS-Ca': {
                                        readonly Value: 78.3;
                                        readonly ValueUnit: "%";
                                    };
                                    readonly 'BS-Mg': {
                                        readonly Value: 17.7;
                                        readonly ValueUnit: "%";
                                    };
                                    readonly 'BS-K': {
                                        readonly Value: 3.9;
                                        readonly ValueUnit: "%";
                                    };
                                };
                            }];
                        }];
                    };
                };
            }];
        };
    }];
};
export = schema;
