declare const schema: {
    readonly $id: "https://formats.openag.io/modus/v1/modus-submit.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Modus document for submitting sample events to FMIS";
    readonly $comment: "Sadly, the standard appears to duplicate a lot of things here from modus-result. Sticking to the standard in the hope of fixing in the future.";
    readonly type: "object";
    readonly properties: {
        readonly _type: {
            readonly $comment: "content type for API responses";
            readonly const: "application/vnd.modus.v1.modus-submit+json";
        };
        readonly Events: {
            readonly type: "array";
            readonly items: {
                readonly $comment: "this is an \"Event\"";
                readonly type: "object";
                readonly properties: {
                    readonly EventMetaData: {
                        readonly $ref: "./global.schema.json#/$defs/EventMetaData";
                    };
                    readonly LabMetaData: {
                        readonly $ref: "./global.schema.json#/$defs/LabMetaData";
                    };
                    readonly FMISMetadata: {
                        readonly $ref: "./global.schema.json#/$defs/FMISMetadata";
                    };
                    readonly SubmissionAttributes: {
                        readonly $ref: "./global.schema.json#/$defs/SubmissionAttributes";
                    };
                    readonly EventSamples: {
                        readonly type: "object";
                        readonly properties: {
                            readonly Soil: {
                                readonly type: "object";
                                readonly properties: {
                                    readonly DepthRefs: {
                                        readonly $ref: "./global.schema.json#/$defs/DepthRefs";
                                    };
                                    readonly RecommendationRefs: {
                                        readonly $ref: "./global.schema.json#/$defs/RecommendationRefs";
                                    };
                                    readonly SoilSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly $comment: "A \"SoilSample\"";
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly Depths: {
                                                    readonly type: "array";
                                                    readonly items: {
                                                        readonly type: "object";
                                                        readonly properties: {
                                                            readonly DepthID: {
                                                                readonly description: "Depth ID from the Depth Reference";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                    };
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                            readonly Plant: {
                                readonly description: "Element to place samples and results from a plant tissue sample event";
                                readonly type: "object";
                                readonly properties: {
                                    readonly RecommendationRefs: {
                                        readonly $ref: "./global.schema.json#/$defs/RecommendationRefs";
                                    };
                                    readonly PlantSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                            readonly Nematode: {
                                readonly description: "Element to place samples and results from a nematode sample event";
                                readonly type: "object";
                                readonly properties: {
                                    readonly DepthRefs: {
                                        readonly $ref: "./global.schema.json#/$defs/DepthRefs";
                                    };
                                    readonly NematodeSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly Depths: {
                                                    readonly type: "array";
                                                    readonly items: {
                                                        readonly type: "object";
                                                        readonly properties: {
                                                            readonly DepthID: {
                                                                readonly type: "integer";
                                                                readonly minimum: 1;
                                                            };
                                                        };
                                                    };
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                            readonly Water: {
                                readonly type: "object";
                                readonly properties: {
                                    readonly WaterSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly Source: {
                                                    readonly type: "string";
                                                };
                                                readonly NutrientResults: {
                                                    readonly $ref: "./global.schema.json#/$defs/NutrientResults";
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                            readonly Residue: {
                                readonly type: "object";
                                readonly properties: {
                                    readonly ResidueSamples: {
                                        readonly type: "array";
                                        readonly items: {
                                            readonly type: "object";
                                            readonly properties: {
                                                readonly SampleMetaData: {
                                                    readonly $ref: "./global.schema.json#/$defs/SampleMetaData";
                                                };
                                                readonly ResidueResults: {
                                                    readonly $ref: "./global.schema.json#/$defs/ResidueResults";
                                                };
                                                readonly Comments: {
                                                    readonly $ref: "./global.schema.json#/$defs/Comments";
                                                };
                                            };
                                        };
                                    };
                                };
                            };
                        };
                    };
                    readonly Comments: {
                        readonly $ref: "./global.schema.json#/$defs/Comments";
                    };
                    readonly ModusSubmit: {
                        readonly $comment: "can hold an entire ModusSubmit document?";
                        readonly $ref: "#";
                    };
                };
            };
        };
        readonly Version: {
            readonly type: "string";
            readonly default: "1.0";
        };
    };
};
export = schema;
