declare const schema: {
    readonly $id: "https://formats.openag.io/oada.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly definitions: {
        readonly link: {
            readonly $anchor: "link";
            readonly definitions: {
                readonly versioned: {
                    readonly $anchor: "versioned";
                    readonly type: "object";
                    readonly required: readonly ["_rev"];
                    readonly properties: {
                        readonly _rev: {
                            readonly $ref: "#/definitions/_rev";
                        };
                        readonly _id: {
                            readonly $ref: "#/definitions/_id";
                        };
                        readonly _type: {
                            readonly $ref: "#/definitions/_type";
                        };
                    };
                    readonly additionalProperties: false;
                };
                readonly unversioned: {
                    readonly $anchor: "unversioned";
                    readonly type: "object";
                    readonly required: readonly ["_id"];
                    readonly properties: {
                        readonly _id: {
                            readonly $ref: "#/definitions/_id";
                        };
                        readonly _type: {
                            readonly $ref: "#/definitions/_type";
                        };
                    };
                    readonly additionalProperties: false;
                };
            };
            readonly anyOf: readonly [{
                readonly $ref: "#/definitions/link/definitions/versioned";
            }, {
                readonly $ref: "#/definitions/link/definitions/unversioned";
            }];
        };
        readonly key: {
            readonly definitions: {
                readonly reserved: {
                    readonly tsType: string;
                    readonly description: "Key names reserved for OADA use";
                    readonly type: "string";
                    readonly pattern: "^_";
                };
                readonly nonReserved: {
                    readonly tsType: string;
                    readonly description: "Key names not reserved for OADA use";
                    readonly type: "string";
                    readonly pattern: "^[^_]";
                };
            };
        };
        readonly _meta: {
            readonly $comment: "_meta is a versioned link";
            readonly description: "_meta is a link to the meta document for a resources.";
            readonly $ref: "#/definitions/link/definitions/versioned";
        };
        readonly _id: {
            readonly description: "_id identifies a resource in the OADA API.";
            readonly type: "string";
            readonly pattern: "^resources/.*$";
        };
        readonly _type: {
            readonly description: "_type identifies the content-type of a resource in the OADA API.";
            readonly type: "string";
            readonly examples: readonly ["application/vnd.oada.something.1+json"];
        };
        readonly _rev: {
            readonly description: "_rev is the revision for a resource in the OADA API.";
            readonly type: "integer";
        };
        readonly method: {
            readonly description: "The request methods (a la HTTP) supported by OADA";
            readonly enum: readonly ["head", "get", "put", "post", "delete"];
        };
        readonly path: {
            readonly description: "The representation of a path within an OADA server";
            readonly type: "string";
            readonly format: "uri-reference";
        };
    };
};
export = schema;
