declare const schema: {
    readonly $id: "https://formats.openag.io/oada/ainz/rule.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "The format for ainz orchestation rules";
    readonly type: "object";
    readonly properties: {
        readonly type: {
            readonly description: "A field for discriminating the different types of rules";
        };
        readonly list: {
            readonly description: "A path to an OADA list to watch for changes";
            readonly $ref: "../../oada.schema.json#/definitions/path";
        };
        readonly schema: {
            readonly description: "A JSON Schema to which to compare new items in list";
            readonly $ref: "https://json-schema.org/draft/2019-09/schema";
        };
    };
    readonly oneOf: readonly [{
        readonly description: "A rule which \"moves\" (re-indexes) a resource";
        readonly type: "object";
        readonly properties: {
            readonly type: {
                readonly enum: readonly ["reindex"];
            };
            readonly destination: {
                readonly description: "A path to an OADA list to which to add maching items";
                readonly type: "string";
            };
            readonly tree: {
                readonly description: "A tree to use for \"tree PUTs\"";
                readonly type: "object";
                readonly $comment: "Recursive schema breaks schema to TS compiler";
            };
            readonly itemsPath: {
                readonly description: "A JSONPath for resolving the items of an indexed list";
                readonly type: "string";
                readonly examples: readonly ["$.day-index.*.*"];
                readonly default: "$.*";
            };
            readonly meta: {
                readonly description: "An object to PUT on matching items's _meta";
                readonly type: "object";
            };
        };
    }, {
        readonly description: "A rule which creates an OADA job when a resource matches";
        readonly type: "object";
        readonly properties: {
            readonly type: {
                readonly enum: readonly ["job"];
            };
            readonly pointer: {
                readonly description: "A JSON pointer of where in the job config to create a link to the resource";
                readonly type: "string";
                readonly format: "json-pointer";
            };
            readonly job: {
                readonly description: "The job to create. A link to the matching resource will be added to the job.";
                readonly $ref: "../service/job.schema.json#";
            };
        };
    }];
    readonly required: readonly ["type", "list", "schema"];
    readonly examples: readonly [{
        readonly type: "reindex";
        readonly list: "/bookmarks/stuff";
        readonly schema: {
            readonly const: {
                readonly foo: "bar";
            };
        };
        readonly destination: "/bookmarks/foo";
    }, {
        readonly type: "job";
        readonly list: "/bookmarks/stuff";
        readonly schema: {
            readonly const: {
                readonly foo: "bar";
            };
        };
        readonly pointer: "/resource";
        readonly job: {
            readonly service: "coolservice";
            readonly type: "cool";
            readonly config: {
                readonly foo: "bar";
            };
        };
    }];
};
export = schema;
