declare const schema: {
    readonly $id: "https://formats.openag.io/oada/as-harvested/v1.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "The \"as-harvested\" key holds the original data logged during harvest.  This can be collections of time-series harvest data or data that is already geospatially referenced.  A typical \"yield map\" exported from an FMIS system would go here.  Think of this like the \"raw\" data that is used to generate tiled maps.";
    readonly properties: {
        readonly 'yield-moisture-dataset': {
            readonly description: "A link in OADA has at least an _id key and links one resource to another.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
            };
            readonly required: readonly ["_id"];
            readonly type: "object";
        };
        readonly _id: {
            readonly description: "_id identifies a resource in the OADA API.";
            readonly type: "string";
        };
        readonly _rev: {
            readonly description: "_rev is the revision string for a resource in the OADA API.";
            readonly type: "integer";
        };
        readonly _meta: {
            readonly description: "_meta is a link to the meta document for a resources.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
                readonly _rev: {
                    readonly description: "_rev is the revision string for a resource in the OADA API.";
                    readonly type: "integer";
                };
            };
            readonly required: readonly ["_id", "_rev"];
            readonly type: "object";
        };
        readonly _type: {
            readonly enum: readonly ["application/vnd.oada.as-harvested.1+json"];
        };
    };
    readonly additionalProperties: true;
    readonly required: readonly ["_type"];
    readonly type: "object";
    readonly examples: readonly [{
        readonly _id: "resources/kfj20ikejldss";
        readonly _rev: 9;
        readonly _type: "application/vnd.oada.as-harvested.1+json";
        readonly 'yield-moisture-dataset': {
            readonly _id: "resources/02ijfkl3k20ij3fsf";
        };
    }];
};
export = schema;
