declare const schema: {
    readonly $id: "https://formats.openag.io/oada/isoblue/location/v1.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Location data of the machine. Contains time and location";
    readonly properties: {
        readonly templates: {
            readonly description: "templates is a general key for holding a collection of data points indexed by random strings.  Templates serve as prototypes for data points under \"data\" keys. If you have a piece of information that exists is all or almost all of the data points in a particular group of points, you can put the repeated things in templates and then just put the name of the template into the data point.  The full data point is therefore a merge of the template object and the data point itself, with the data point overruling when there are any keys that exist in both objects.  Schema is therefore identical to \"data\".";
            readonly patternProperties: {
                readonly '^(?!(indexing|.*-index|_.*)).*$': {
                    readonly description: "data-point never appears as a word in any document or URL.  It is a general type of object that can hold any type of data.  It represents the type of object that can sit under \"data\" or \"templates\".";
                    readonly properties: {
                        readonly id: {
                            readonly description: "id (note this is NOT \"_id\") can be used to identify a particular data point, perhaps across documents which simply re-index the same data.";
                            readonly type: "string";
                        };
                        readonly time: {
                            readonly description: "time is a data type which holds a reading of...time...";
                            readonly properties: {
                                readonly units: {
                                    readonly type: "string";
                                    readonly examples: readonly ["unix-timestamp", "sec"];
                                };
                            };
                            readonly type: "object";
                        };
                        readonly location: {
                            readonly description: "location represents a point in space, usually a GPS coordinate or geohash";
                            readonly properties: {
                                readonly datum: {
                                    readonly description: "datum describes the model of the earth used for GPS coordinates.  It can be from a set of known strings, or an EPSG model from http://spatialreference.org";
                                    readonly anyOf: readonly [{
                                        readonly type: "string";
                                        readonly examples: readonly ["WGS84"];
                                    }, {
                                        readonly required: readonly ["type", "properties"];
                                        readonly properties: {
                                            readonly type: {
                                                readonly enum: readonly ["EPSG"];
                                            };
                                            readonly properties: {
                                                readonly required: readonly ["code"];
                                                readonly properties: {
                                                    readonly code: {
                                                        readonly type: "number";
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                        };
                                        readonly type: "object";
                                    }];
                                };
                                readonly latitude: {
                                    readonly description: "latitude is a string in the format of a number";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly longitude: {
                                    readonly description: "longitude is a string in the format of a number";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly altitude: {
                                    readonly description: "altitude is a string in the format of a number";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly lat: {
                                    readonly description: "lat is shorthand for latitude";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly lon: {
                                    readonly description: "lon is shorthand for longitude";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly alt: {
                                    readonly description: "alt is shorthand for altitude";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly geohash: {
                                    readonly description: "A geohash is a base 32 encoded string which represents the combination of latitude and longitude into a single number which, in general, has a property such that points close in number are close on the globe.";
                                    readonly type: "string";
                                    readonly pattern: "^[0-9bcdefghjkmnpqrstuvwxyz]+$";
                                };
                            };
                            readonly type: "object";
                        };
                    };
                    readonly type: "object";
                };
            };
        };
        readonly data: {
            readonly description: "data is a general key for holding a collection of data points indexed by random strings.";
            readonly patternProperties: {
                readonly '^(?!(indexing|.*-index|_.*)).*$': {
                    readonly description: "data-point never appears as a word in any document or URL.  It is a general type of object that can hold any type of data.  It represents the type of object that can sit under \"data\" or \"templates\".";
                    readonly properties: {
                        readonly id: {
                            readonly description: "id (note this is NOT \"_id\") can be used to identify a particular data point, perhaps across documents which simply re-index the same data.";
                            readonly type: "string";
                        };
                        readonly time: {
                            readonly description: "time is a data type which holds a reading of...time...";
                            readonly properties: {
                                readonly units: {
                                    readonly type: "string";
                                    readonly examples: readonly ["unix-timestamp", "sec"];
                                };
                            };
                            readonly type: "object";
                        };
                        readonly location: {
                            readonly description: "location represents a point in space, usually a GPS coordinate or geohash";
                            readonly properties: {
                                readonly datum: {
                                    readonly description: "datum describes the model of the earth used for GPS coordinates.  It can be from a set of known strings, or an EPSG model from http://spatialreference.org";
                                    readonly anyOf: readonly [{
                                        readonly type: "string";
                                        readonly examples: readonly ["WGS84"];
                                    }, {
                                        readonly required: readonly ["type", "properties"];
                                        readonly properties: {
                                            readonly type: {
                                                readonly enum: readonly ["EPSG"];
                                            };
                                            readonly properties: {
                                                readonly required: readonly ["code"];
                                                readonly properties: {
                                                    readonly code: {
                                                        readonly type: "number";
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                        };
                                        readonly type: "object";
                                    }];
                                };
                                readonly latitude: {
                                    readonly description: "latitude is a string in the format of a number";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly longitude: {
                                    readonly description: "longitude is a string in the format of a number";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly altitude: {
                                    readonly description: "altitude is a string in the format of a number";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly lat: {
                                    readonly description: "lat is shorthand for latitude";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly lon: {
                                    readonly description: "lon is shorthand for longitude";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly alt: {
                                    readonly description: "alt is shorthand for altitude";
                                    readonly type: "string";
                                    readonly pattern: "^-?([0-9]*[.])[0-9]+";
                                };
                                readonly geohash: {
                                    readonly description: "A geohash is a base 32 encoded string which represents the combination of latitude and longitude into a single number which, in general, has a property such that points close in number are close on the globe.";
                                    readonly type: "string";
                                    readonly pattern: "^[0-9bcdefghjkmnpqrstuvwxyz]+$";
                                };
                            };
                            readonly type: "object";
                        };
                    };
                    readonly required: readonly ["id", "time", "location"];
                    readonly type: "object";
                };
            };
        };
        readonly _id: {
            readonly description: "_id identifies a resource in the OADA API.";
            readonly type: "string";
        };
        readonly _rev: {
            readonly description: "_rev is the revision string for a resource in the OADA API.";
            readonly type: "integer";
        };
        readonly _meta: {
            readonly description: "_meta is a link to the meta document for a resources.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
                readonly _rev: {
                    readonly description: "_rev is the revision string for a resource in the OADA API.";
                    readonly type: "integer";
                };
            };
            readonly required: readonly ["_id", "_rev"];
            readonly type: "object";
        };
        readonly _type: {
            readonly enum: readonly ["application/vnd.oada.isoblue.location.1+json"];
        };
        readonly indexing: {
            readonly type: "array";
            readonly items: {
                readonly anyOf: readonly [{
                    readonly properties: {
                        readonly index: {
                            readonly enum: readonly ["year-index"];
                        };
                        readonly source: {
                            readonly enum: readonly ["oada.vocab.year-index"];
                        };
                        readonly value: {
                            readonly type: "string";
                            readonly pattern: "^[0-9]{4}$";
                        };
                    };
                    readonly type: "object";
                }, {
                    readonly properties: {
                        readonly index: {
                            readonly enum: readonly ["day-index"];
                        };
                        readonly source: {
                            readonly enum: readonly ["oada.vocab.day-index"];
                        };
                        readonly value: {
                            readonly type: "string";
                            readonly pattern: "^[0-9]{4}-[0-9]{2}-[0-9]{2}$";
                        };
                    };
                    readonly type: "object";
                }, {
                    readonly properties: {
                        readonly index: {
                            readonly enum: readonly ["hour-index"];
                        };
                        readonly source: {
                            readonly enum: readonly ["oada.vocab.hour-index"];
                        };
                        readonly value: {
                            readonly type: "string";
                            readonly pattern: "^[0-9]{2}:[0-9]{2}$";
                        };
                    };
                    readonly type: "object";
                }];
            };
        };
        readonly 'year-index': {
            readonly description: "year-index splits things up by a 4-digit year";
            readonly patternProperties: {
                readonly '^[0-9]{4}$': {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
            };
        };
        readonly 'day-index': {
            readonly description: "day-index splits things up by days, with full year-month-day string for keys";
            readonly patternProperties: {
                readonly '^[0-9]{4}-[0-9]{2}-[0-9]{2}$': {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
            };
        };
        readonly 'hour-index': {
            readonly description: "hour-index splits things up by hours, 24-hour time string in GMT like 06:07 or 23:44";
            readonly patternProperties: {
                readonly '^[0-9]{2}:[0-9]{2}$': {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
            };
        };
    };
    readonly additionalProperties: true;
    readonly required: readonly ["_type"];
    readonly type: "object";
    readonly examples: readonly [];
};
export = schema;
