declare const schema: {
    readonly $id: "https://formats.openag.io/oada/sensor-hubs/v1.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Holds a listing of links to various sensor hubs (each hub may have many sensors it is responsible for";
    readonly properties: {
        readonly 'serial-numbers': {
            readonly description: "serial-numbers is an object whose keys represent serial numbers of something (i.e. a sensor hub), and each key just links to that thing";
            readonly patternProperties: {
                readonly '^(?!(indexing|.*-index|_.*)).*$': {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
            };
        };
        readonly _id: {
            readonly description: "_id identifies a resource in the OADA API.";
            readonly type: "string";
        };
        readonly _rev: {
            readonly description: "_rev is the revision string for a resource in the OADA API.";
            readonly type: "integer";
        };
        readonly _meta: {
            readonly description: "_meta is a link to the meta document for a resources.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
                readonly _rev: {
                    readonly description: "_rev is the revision string for a resource in the OADA API.";
                    readonly type: "integer";
                };
            };
            readonly required: readonly ["_id", "_rev"];
            readonly type: "object";
        };
        readonly _type: {
            readonly enum: readonly ["application/vnd.oada.sensor-hubs.1+json"];
        };
    };
    readonly additionalProperties: true;
    readonly required: readonly ["_type"];
    readonly type: "object";
    readonly examples: readonly [{
        readonly _type: "application/vnd.oada.sensor-hubs.1+json";
        readonly 'serial-numbers': {
            readonly df874j3: {
                readonly _id: "8f2ofj2308f2i";
            };
            readonly '02kjf20': {
                readonly _id: "mxmxh92f8hsdf";
            };
        };
    }];
};
export = schema;
