declare const schema: {
    readonly $id: "https://formats.openag.io/oada/tiled-maps/moisture-map/v1.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "The \"moisture-map\" document contains harvested moisture readingstrade moisture, aggregated at various zoom levels for mapping and fast statistical calculation";
    readonly properties: {
        readonly datum: {
            readonly description: "datum describes the model of the earth used for GPS coordinates.  It can be from a set of known strings, or an EPSG model from http://spatialreference.org";
            readonly anyOf: readonly [{
                readonly type: "string";
                readonly examples: readonly ["WGS84"];
            }, {
                readonly required: readonly ["type", "properties"];
                readonly properties: {
                    readonly type: {
                        readonly enum: readonly ["EPSG"];
                    };
                    readonly properties: {
                        readonly required: readonly ["code"];
                        readonly properties: {
                            readonly code: {
                                readonly type: "number";
                            };
                        };
                        readonly type: "object";
                    };
                };
                readonly type: "object";
            }];
        };
        readonly stats: {
            readonly description: "stats sits at the top of a resource to list stats about the data inside that resource. Basic stats are sum, count, sum-of-squares.  The actual keys under stats are data names that you have stats for like weight, area, etc.  The same units and data names are valid under stats that are valid under data";
            readonly properties: {
                readonly template: {
                    readonly description: "template sits inside a data point and gives the name of a template (key in the templates object) which serves as prototype for a given data point.  The full data point is the merge of that template object with the data point, with the data point taking precedence in key collisions. This is a string because its value is the key in templates, not the template itself.";
                    readonly type: "string";
                };
                readonly geohash: {
                    readonly description: "A geohash is a base 32 encoded string which represents the combination of latitude and longitude into a single number which, in general, has a property such that points close in number are close on the globe.";
                    readonly type: "string";
                    readonly pattern: "^[0-9bcdefghjkmnpqrstuvwxyz]+$";
                };
                readonly area: {
                    readonly description: "area is a data type which holds a reading of...area...";
                    readonly properties: {
                        readonly units: {
                            readonly type: "string";
                            readonly examples: readonly ["ac", "acres", "ha", "hectares", "sqft"];
                        };
                    };
                    readonly type: "object";
                };
                readonly moisture: {
                    readonly description: "moisture is a data type which holds a reading of the amount of moisture in a crop. It is typically in units of % water (%H2O).";
                    readonly properties: {
                        readonly units: {
                            readonly type: "string";
                            readonly examples: readonly ["%H2O"];
                        };
                    };
                    readonly type: "object";
                };
            };
            readonly type: "object";
        };
        readonly templates: {
            readonly description: "templates is a general key for holding a collection of data points indexed by random strings.  Templates serve as prototypes for data points under \"data\" keys. If you have a piece of information that exists is all or almost all of the data points in a particular group of points, you can put the repeated things in templates and then just put the name of the template into the data point.  The full data point is therefore a merge of the template object and the data point itself, with the data point overruling when there are any keys that exist in both objects.  Schema is therefore identical to \"data\".";
            readonly patternProperties: {
                readonly '^(?!(indexing|.*-index|_.*)).*$': {
                    readonly description: "data-point never appears as a word in any document or URL.  It is a general type of object that can hold any type of data.  It represents the type of object that can sit under \"data\" or \"templates\".";
                    readonly properties: {
                        readonly template: {
                            readonly description: "template sits inside a data point and gives the name of a template (key in the templates object) which serves as prototype for a given data point.  The full data point is the merge of that template object with the data point, with the data point taking precedence in key collisions. This is a string because its value is the key in templates, not the template itself.";
                            readonly type: "string";
                        };
                        readonly geohash: {
                            readonly description: "A geohash is a base 32 encoded string which represents the combination of latitude and longitude into a single number which, in general, has a property such that points close in number are close on the globe.";
                            readonly type: "string";
                            readonly pattern: "^[0-9bcdefghjkmnpqrstuvwxyz]+$";
                        };
                        readonly area: {
                            readonly description: "area is a data type which holds a reading of...area...";
                            readonly properties: {
                                readonly units: {
                                    readonly type: "string";
                                    readonly examples: readonly ["ac", "acres", "ha", "hectares", "sqft"];
                                };
                            };
                            readonly type: "object";
                        };
                        readonly moisture: {
                            readonly description: "moisture is a data type which holds a reading of the amount of moisture in a crop. It is typically in units of % water (%H2O).";
                            readonly properties: {
                                readonly units: {
                                    readonly type: "string";
                                    readonly examples: readonly ["%H2O"];
                                };
                            };
                            readonly type: "object";
                        };
                    };
                    readonly type: "object";
                };
            };
        };
        readonly 'geohash-data': {
            readonly description: "geohash-data is much like \"geohash-index\" except that the geohash strings in geohashes are links to resources, whereas in geohash-data the geohash strings are actual data points representing data values for that geohash.  This is used primarily in tiled-maps.  The allowable values are the same as the values under \"data\"";
            readonly patternProperties: {
                readonly '^[0-9bcdefghjkmnpqrstuvwxyz]+$': {
                    readonly description: "data-point never appears as a word in any document or URL.  It is a general type of object that can hold any type of data.  It represents the type of object that can sit under \"data\" or \"templates\".";
                    readonly properties: {
                        readonly template: {
                            readonly description: "template sits inside a data point and gives the name of a template (key in the templates object) which serves as prototype for a given data point.  The full data point is the merge of that template object with the data point, with the data point taking precedence in key collisions. This is a string because its value is the key in templates, not the template itself.";
                            readonly type: "string";
                        };
                        readonly geohash: {
                            readonly description: "A geohash is a base 32 encoded string which represents the combination of latitude and longitude into a single number which, in general, has a property such that points close in number are close on the globe.";
                            readonly type: "string";
                            readonly pattern: "^[0-9bcdefghjkmnpqrstuvwxyz]+$";
                        };
                        readonly area: {
                            readonly description: "area is a data type which holds a reading of...area...";
                            readonly properties: {
                                readonly units: {
                                    readonly type: "string";
                                    readonly examples: readonly ["ac", "acres", "ha", "hectares", "sqft"];
                                };
                            };
                            readonly type: "object";
                        };
                        readonly moisture: {
                            readonly description: "moisture is a data type which holds a reading of the amount of moisture in a crop. It is typically in units of % water (%H2O).";
                            readonly properties: {
                                readonly units: {
                                    readonly type: "string";
                                    readonly examples: readonly ["%H2O"];
                                };
                            };
                            readonly type: "object";
                        };
                    };
                    readonly required: readonly ["area", "moisture"];
                    readonly type: "object";
                };
            };
        };
        readonly _id: {
            readonly description: "_id identifies a resource in the OADA API.";
            readonly type: "string";
        };
        readonly _rev: {
            readonly description: "_rev is the revision string for a resource in the OADA API.";
            readonly type: "integer";
        };
        readonly _meta: {
            readonly description: "_meta is a link to the meta document for a resources.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
                readonly _rev: {
                    readonly description: "_rev is the revision string for a resource in the OADA API.";
                    readonly type: "integer";
                };
            };
            readonly required: readonly ["_id", "_rev"];
            readonly type: "object";
        };
        readonly _type: {
            readonly enum: readonly ["application/vnd.oada.tiled-maps.moisture-map.1+json"];
        };
        readonly indexing: {
            readonly type: "array";
            readonly items: {
                readonly anyOf: readonly [{
                    readonly properties: {
                        readonly index: {
                            readonly enum: readonly ["year-index"];
                        };
                        readonly source: {
                            readonly enum: readonly ["oada.vocab.year-index"];
                        };
                        readonly value: {
                            readonly type: "string";
                            readonly pattern: "^[0-9]{4}$";
                        };
                    };
                    readonly type: "object";
                }, {
                    readonly properties: {
                        readonly index: {
                            readonly enum: readonly ["crop-index"];
                        };
                        readonly value: {
                            readonly type: "string";
                            readonly examples: readonly ["corn", "soybeans", "wheat"];
                        };
                        readonly source: {
                            readonly type: "string";
                            readonly examples: readonly ["oada.vocab.crop-type"];
                        };
                    };
                    readonly type: "object";
                }, {
                    readonly properties: {
                        readonly index: {
                            readonly enum: readonly ["geohash-length-index"];
                        };
                        readonly value: {
                            readonly type: "string";
                            readonly pattern: "^geohash-[1-9][0-9]*$";
                        };
                        readonly source: {
                            readonly type: "string";
                            readonly examples: readonly ["oada.vocab.geohash-length-index"];
                        };
                    };
                    readonly type: "object";
                }, {
                    readonly properties: {
                        readonly index: {
                            readonly enum: readonly ["geohash-index"];
                        };
                        readonly value: {
                            readonly description: "A geohash is a base 32 encoded string which represents the combination of latitude and longitude into a single number which, in general, has a property such that points close in number are close on the globe.";
                            readonly type: "string";
                            readonly pattern: "^[0-9bcdefghjkmnpqrstuvwxyz]+$";
                        };
                        readonly source: {
                            readonly type: "string";
                            readonly examples: readonly ["oada.vocab.geohash"];
                        };
                    };
                    readonly type: "object";
                }];
            };
        };
        readonly 'year-index': {
            readonly description: "year-index splits things up by a 4-digit year";
            readonly patternProperties: {
                readonly '^[0-9]{4}$': {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
            };
        };
        readonly 'crop-index': {
            readonly description: "crop-index is an object that sits inside other objects and gives links to documents based on the name of a particular crop. It's known keys are also not considered part of the OADA vocabulary and therefore do not appear as vocabulary terms even though they will be in OADA URLs.  This is standard for indexes.";
            readonly properties: {
                readonly corn: {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
                readonly soybeans: {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
                readonly wheat: {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
            };
            readonly type: "object";
        };
        readonly 'geohash-length-index': {
            readonly $ref: "../../indexes/geohash-length-index.schema.json";
        };
        readonly 'geohash-index': {
            readonly description: "geohash-index is a key that holds under it a set of geohash keys of a particular length.  It is necessary because some geohashes may be legitimate words and therefore we need to place all the geohashes specifically under one key. This key usually sits at the top-level of a document reached via a geohash-length-index. It is intended to hold links to resources containing data that is grouped under a particular geohash.";
            readonly patternProperties: {
                readonly '^[0-9bcdefghjkmnpqrstuvwxyz]+$': {
                    readonly description: "A link in OADA has at least an _id key and links one resource to another.";
                    readonly properties: {
                        readonly _id: {
                            readonly description: "_id identifies a resource in the OADA API.";
                            readonly type: "string";
                        };
                    };
                    readonly required: readonly ["_id"];
                    readonly type: "object";
                };
            };
        };
    };
    readonly additionalProperties: true;
    readonly required: readonly ["_type"];
    readonly type: "object";
    readonly examples: readonly [{
        readonly _id: "resources/k2fjo23lf3";
        readonly _rev: 9;
        readonly _type: "application/vnd.oada.tiled-maps.moisture-map.1+json";
        readonly indexing: readonly [{
            readonly index: "year-index";
            readonly source: "oada.vocab.year-index";
            readonly value: "2019";
        }, {
            readonly index: "crop-index";
            readonly source: "oada.vocab.year-index";
            readonly value: "corn";
        }, {
            readonly index: "geohash-length-index";
            readonly source: "oada.vocab.geohash-length-index";
            readonly value: "geohash-7";
        }, {
            readonly index: "geohash-index";
            readonly source: "oada.vocab.geohash-index";
            readonly value: "dpq78df";
        }];
        readonly stats: {
            readonly moisture: {
                readonly units: "%H2O";
                readonly sum: 123123.4124;
                readonly 'sum-of-squares': 1412413.234234;
                readonly count: 1243;
            };
            readonly area: {
                readonly units: "acres";
                readonly sum: 1451341.34233;
                readonly 'sum-of-squares': 134134124.3413412;
                readonly count: 1243;
            };
        };
        readonly templates: {
            readonly '123': {
                readonly area: {
                    readonly units: "ac";
                };
                readonly moisture: {
                    readonly units: "%H2O";
                };
            };
        };
        readonly datum: "WGS84";
        readonly 'geohash-data': {
            readonly '023jf2d': {
                readonly template: "123";
                readonly geohash: "023jf2d";
                readonly moisture: {
                    readonly sum: 123123.4124;
                    readonly 'sum-of-squares': 1412413.234234;
                    readonly count: 1243;
                };
                readonly area: {
                    readonly sum: 1451341.34233;
                    readonly 'sum-of-squares': 134134124.3413412;
                    readonly count: 1243;
                };
            };
            readonly '023jf2e': {
                readonly template: "123";
                readonly geohash: "023jf2e";
                readonly moisture: {
                    readonly sum: 123123.4124;
                    readonly 'sum-of-squares': 1412413.234234;
                    readonly count: 1243;
                };
                readonly area: {
                    readonly sum: 1451341.34233;
                    readonly 'sum-of-squares': 134134124.3413412;
                    readonly count: 1243;
                };
            };
        };
    }];
};
export = schema;
