declare const schema: {
    readonly $id: "https://formats.openag.io/oada/tiled-maps/v1.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "tiled-maps is used for visualization and statistical calculations, and just generally for making arbitrary geospatial queries. A tiled map is generated from the as-harvested source data which is  turned into a set of data tiles at various zoom levels.  A mobile device or other map-based viewer can request documents with data combined to whatever zoom level it needs.  In addition, each tile in the map contains statistical computations for all the underlying data represented at that zoom level.  This means that if you want to take an average of an area that completely contains a particular tile, you only need to  get the stats for that tile, rather than iterating over the underlying data. In reality, the value for a given \"pixel\" in a tile is just the stats object of the much smaller geohash that sits on that pixel.";
    readonly properties: {
        readonly 'dry-yield-map': {
            readonly description: "A link in OADA has at least an _id key and links one resource to another.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
            };
            readonly required: readonly ["_id"];
            readonly type: "object";
        };
        readonly 'moisture-map': {
            readonly description: "A link in OADA has at least an _id key and links one resource to another.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
            };
            readonly required: readonly ["_id"];
            readonly type: "object";
        };
        readonly _id: {
            readonly description: "_id identifies a resource in the OADA API.";
            readonly type: "string";
        };
        readonly _rev: {
            readonly description: "_rev is the revision string for a resource in the OADA API.";
            readonly type: "integer";
        };
        readonly _meta: {
            readonly description: "_meta is a link to the meta document for a resources.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
                readonly _rev: {
                    readonly description: "_rev is the revision string for a resource in the OADA API.";
                    readonly type: "integer";
                };
            };
            readonly required: readonly ["_id", "_rev"];
            readonly type: "object";
        };
        readonly _type: {
            readonly enum: readonly ["application/vnd.oada.tiled-maps.1+json"];
        };
    };
    readonly additionalProperties: true;
    readonly required: readonly ["_type"];
    readonly type: "object";
    readonly examples: readonly [{
        readonly _id: "resources/029jfilwkjfo2i3ledkf";
        readonly _rev: 5;
        readonly _type: "application/vnd.oada.tiled-maps.1+json";
        readonly 'dry-yield-map': {
            readonly _id: "resources/k2fjo23lf3";
        };
        readonly 'moisture-map': {
            readonly _id: "resources/k2fjo23lf3";
        };
    }];
};
export = schema;
