declare const _default: {
    readonly type: "object";
    readonly examples: readonly [{
        readonly client_id: "3klaxu838akahf38acucaix73";
        readonly client_id_issued_at: 1418423102;
        readonly software_version: "1.0-ga";
        readonly scopes: "read:planting.prescriptions write:fields";
        readonly redirect_uris: readonly ["https://client.example.com/callback", "https://client.example.com/cb"];
        readonly token_endpoint_auth_method: "urn:ietf:params:oauth:client-assertion-type:jwt-bearer";
        readonly grant_types: readonly ["implicit", "authorization_code", "refresh_token"];
        readonly response_types: readonly ["token", "code"];
        readonly client_name: "Example OADA Client";
        readonly client_uri: "http://example.com";
        readonly logo_uri: "http://example.com/logo.png";
        readonly contacts: readonly ["Clint Client <cclient@example.com>"];
        readonly tos_uri: "http://example.com/tos.html";
        readonly policy_uri: "http://example.com/policy.html";
        readonly software_id: "djxkjau3n937xz7jakl3";
        readonly registration_provider: "registration.example.com";
    }];
    readonly properties: {
        [x: string]: {
            readonly description: `${string}\n@see {@link ${string}}`;
        };
        redirect_uris: {
            type: string;
            uniqueItems: boolean;
            items: {
                type: string;
                format: string;
            };
        };
        token_endpoint_auth_method: {
            type: string;
            oneOf: ({
                const: string;
                description: string;
                $ref?: undefined;
            } | {
                $ref: string;
                const?: undefined;
                description?: undefined;
            })[];
        };
        grant_types: {
            type: string;
            minItems: number;
            uniqueItems: boolean;
            items: {
                type: string;
                oneOf: ({
                    const: string;
                    description: string;
                    $ref?: undefined;
                } | {
                    $ref: string;
                    const?: undefined;
                    description?: undefined;
                })[];
            };
        };
        response_types: {
            type: string;
            uniqueItems: boolean;
            items: {
                type: string;
            };
            default: string[];
        };
        client_name: {
            type: string;
        };
        client_uri: {
            type: string;
            format: string;
        };
        logo_uri: {
            type: string;
            format: string;
        };
        scope: {
            type: string;
        };
        contacts: {
            type: string;
            uniqueItems: boolean;
            items: {
                type: string;
            };
        };
        tos_uri: {
            type: string;
            format: string;
        };
        policy_uri: {
            type: string;
            format: string;
        };
        jwks_uri: {
            type: string;
            format: string;
        };
        jwks: {
            $ref: string;
        };
        software_id: {
            type: string;
        };
        software_version: {
            type: string;
        };
        software_statement: {
            type: string;
            description: string;
        };
        client_id: {
            type: string;
        };
        client_secret: {
            type: string;
        };
        client_id_issued_at: {
            type: string;
        };
        client_secret_expires_at: {
            type: string;
        };
        application_type: {
            type: string;
            enum: string[];
            default: string;
        };
        sector_identifier_uri: {
            type: string;
            format: string;
            pattern: string;
        };
        subject_type: {
            enum: string[];
        };
        id_token_signed_response_alg: {
            $ref: string;
        };
        id_token_encrypted_response_alg: {
            $ref: string;
        };
        id_token_encrypted_response_enc: {
            $ref: string;
        };
        userinfo_signed_response_alg: {
            $ref: string;
        };
        userinfo_encrypted_response_alg: {
            $ref: string;
        };
        userinfo_encrypted_response_enc: {
            $ref: string;
        };
        request_object_signing_alg: {
            $ref: string;
        };
        request_object_encryption_alg: {
            $ref: string;
        };
        request_object_encryption_enc: {
            $ref: string;
        };
        token_endpoint_auth_signing_alg: {
            $ref: string;
        };
        default_max_age: {
            type: string;
        };
        require_auth_time: {
            type: string;
        };
        default_acr_values: {
            type: string;
            uniqueItems: boolean;
            items: {
                type: string;
            };
        };
        initiate_login_uri: {
            type: string;
            format: string;
            pattern: string;
        };
        request_uris: {
            type: string;
            uniqueItems: boolean;
            items: {
                type: string;
                format: string;
            };
        };
        claims_redirect_uris: {
            type: string;
            uniqueItems: boolean;
            items: {
                type: string;
                format: string;
            };
        };
        nfv_token_signed_response_alg: {
            $ref: string;
        };
        nfv_token_encrypted_response_alg: {
            $ref: string;
        };
        nfv_token_encrypted_response_enc: {
            $ref: string;
        };
        tls_client_certificate_bound_access_tokens: {
            type: string;
            default: boolean;
        };
        tls_client_auth_subject_dn: {
            type: string;
        };
        tls_client_auth_san_dns: {
            type: string;
        };
        tls_client_auth_san_uri: {
            type: string;
            format: string;
        };
        tls_client_auth_san_ip: {
            type: string;
            oneOf: {
                format: string;
            }[];
        };
        tls_client_auth_san_email: {
            type: string;
            format: string;
        };
        require_signed_request_object: {
            type: string;
            default: boolean;
        };
        require_pushed_authorization_requests: {
            type: string;
            default: boolean;
        };
        introspection_signed_response_alg: {
            $ref: string;
        };
        introspection_encrypted_response_alg: {
            $ref: string;
        };
        introspection_encrypted_response_enc: {
            $ref: string;
        };
        frontchannel_logout_uri: {
            type: string;
            format: string;
        };
        frontchannel_logout_session_required: {
            type: string;
            default: boolean;
        };
        backchannel_logout_uri: {
            type: string;
            format: string;
        };
        backchannel_logout_session_required: {
            type: string;
            default: boolean;
        };
        post_logout_redirect_uris: {
            type: string;
            uniqueItems: boolean;
            items: {
                type: string;
                format: string;
            };
        };
        authorization_details_types: {
            type: string;
            uniqueItems: boolean;
            items: {
                type: string;
            };
        };
        dpop_bound_access_tokens: {
            type: string;
            default: boolean;
        };
    };
    readonly $id: "https://formats.openag.io/oauth-dyn-reg/metadata.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly title: "application/vnd.oada.oauth-dny-reg.register-response.1+json";
    readonly description: "@see {@link https://datatracker.ietf.org/doc/html/rfc7591#section-2 Client Metadata}";
    readonly definitions: {
        readonly extension_grant_uri: {
            readonly $comment: `Enum retrieved dynamically from https://www.iana.org/assignments/oauth-parameters/oauth-parameters.xhtml#uri on ${string}`;
            readonly description: "Grant type extension URIs";
            readonly oneOf: {
                title: string;
                description: `${string}\n@see {@link ${string}}`;
                const: string;
            }[];
        };
        readonly extension_client_assertion_uri: {
            readonly $comment: `Enum retrieved dynamically from https://www.iana.org/assignments/oauth-parameters/oauth-parameters.xhtml#uri on ${string}`;
            readonly description: "Grant type URI extension strings";
            readonly oneOf: {
                title: string;
                description: `${string}\n@see {@link ${string}}`;
                const: string;
            }[];
        };
        readonly jws_alg: {
            readonly $comment: "TODO: need to update this to use the new jws schema";
            readonly $ref: "https://formats.openag.io/jose/jwa.schema.json#/definitions/alg";
        };
        readonly jwe_alg: {
            readonly $comment: "TODO: need to update this to use the new jwe schema";
            readonly $ref: "https://formats.openag.io/jose/jwa.schema.json#/definitions/alg";
        };
        readonly jwe_enc: {
            readonly $comment: "TODO: need to update this to use the new jwe schema";
            readonly type: "string";
        };
    };
};
export default _default;
