declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/gs1/produce/shipping_event/v1.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "GS1 receiving event has certain required fields and and array element";
    readonly properties: {
        readonly originator: {
            readonly description: "gln of the data originator and the data owner";
            readonly type: "string";
        };
        readonly trading_partner: {
            readonly description: "gln of the trading partner";
            readonly type: "string";
        };
        readonly activity_type: {
            readonly description: "defines the business process that taking place";
            readonly type: "string";
            readonly examples: readonly ["purchase_order", "production_work_order", "bill_of_landing"];
        };
        readonly originator_type: {
            readonly description: "trading_partner_type of the originating trading partner";
            readonly type: "string";
            readonly examples: readonly ["grower", "supplier", "manufacturer", "processor", "distributor", "retailor"];
        };
        readonly receiver_type: {
            readonly description: "trading_partner_type of the receiving trading partner";
            readonly type: "string";
            readonly examples: readonly ["grower", "supplier", "manufacturer", "processor", "distributor", "retailor"];
        };
        readonly timestamp: {
            readonly description: "defines the timestamp of the data capture";
            readonly type: "string";
        };
        readonly activity_no: {
            readonly description: "defines a unique identifier to implicate the transaction id of the business event - purchase order id etc";
            readonly type: "string";
        };
        readonly contents_of_shipment: {
            readonly description: "all shipping trading items";
            readonly type: "array";
            readonly items: {
                readonly description: "item is sold/shipped by one trading partner to the other";
            };
        };
        readonly _id: {
            readonly description: "_id identifies a resource in the OADA API.";
            readonly type: "string";
        };
        readonly _rev: {
            readonly description: "_rev is the revision string for a resource in the OADA API.";
            readonly type: "integer";
        };
        readonly _meta: {
            readonly description: "_meta is a link to the meta document for a resources.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
                readonly _rev: {
                    readonly description: "_rev is the revision string for a resource in the OADA API.";
                    readonly type: "integer";
                };
            };
            readonly required: readonly ["_id", "_rev"];
            readonly type: "object";
        };
        readonly _type: {
            readonly enum: readonly ["application/trellis.vnd.gs1.produce.shipping_event.1+json"];
        };
    };
    readonly additionalProperties: true;
    readonly required: readonly ["_type"];
    readonly type: "object";
    readonly examples: readonly [];
};
export = schema;
