declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/rules/action.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "A description of an action which can be used in OADA rules";
    readonly allOf: readonly [{
        readonly $ref: "../../oada/resource.schema.json";
    }];
    readonly properties: {
        readonly name: {
            readonly description: "Name of the action";
            readonly type: "string";
            readonly examples: readonly ["email", "push audit"];
        };
        readonly service: {
            readonly description: "Name of the service implementing/performing the action";
            readonly type: "string";
        };
        readonly type: {
            readonly description: "Content-type(s) with which this action works";
            readonly oneOf: readonly [{
                readonly type: "string";
            }, {
                readonly type: "array";
                readonly items: {
                    readonly type: "string";
                };
            }];
        };
        readonly description: {
            readonly description: "Human description of the action for UI etc.";
            readonly type: "string";
            readonly examples: readonly ["send an email to {{address}}"];
        };
        readonly uischema: {
            readonly description: "UISchema for the params";
            readonly $comment: "Not sure this is a good idea";
            readonly type: "object";
        };
        readonly params: {
            readonly description: "Input parameters for the action";
            readonly $ref: "https://json-schema.org/draft/2019-09/schema";
        };
    };
    readonly required: readonly ["name", "service", "type", "description"];
};
export = schema;
