declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/rules/compiled.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Represents a \"compiled\" bit of work to implement rules";
    readonly allOf: readonly [{
        readonly $ref: "../../oada/resource.schema.json";
    }];
    readonly properties: {
        readonly rule: {
            readonly description: "Reference to the rule this is implementing";
            readonly $ref: "../../oada/link/v1.schema.json#/definitions/versioned";
        };
        readonly action: {
            readonly description: "Name of the action invloved";
            readonly type: "string";
            readonly examples: readonly ["push audit"];
        };
        readonly service: {
            readonly description: "Name of the service performing this piece of work";
            readonly type: "string";
        };
        readonly schema: {
            readonly description: "A JSON Schema which filters inputs to this work";
            readonly $ref: "https://json-schema.org/draft/2019-09/schema";
        };
        readonly path: {
            readonly description: "The path to an OADA list to watch for inputs";
            readonly $ref: "../../oada.schema.json#/definitions/path";
        };
        readonly type: {
            readonly description: "Content-type(s) with which this works";
            readonly oneOf: readonly [{
                readonly type: "string";
            }, {
                readonly type: "array";
                readonly items: {
                    readonly type: "string";
                };
            }];
        };
        readonly on: {
            readonly $comment: "Where should this definiton live?";
            readonly $ref: "./configured.schema.json#/properties/on";
        };
        readonly options: {
            readonly description: "Parameter values for this work";
            readonly $comment: "Should these live in parent rule?";
            readonly type: "object";
        };
    };
    readonly required: readonly ["rule", "action", "service", "type", "on", "path", "schema"];
};
export = schema;
