declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/rules/condition.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "A description of a condtion which can be used in OADA rules";
    readonly allOf: readonly [{
        readonly $ref: "../../oada/resource.schema.json";
    }];
    readonly properties: {
        readonly name: {
            readonly description: "Name of the condition";
            readonly type: "string";
            readonly examples: readonly ["signature_valid"];
        };
        readonly service: {
            readonly description: "Name of the service implementing/performing the condition";
            readonly type: "string";
            readonly $comment: "service conditions not yet implemented";
        };
        readonly schema: {
            readonly description: "A JSON Schema to which implements this condition";
            readonly $ref: "https://json-schema.org/draft/2019-09/schema";
        };
        readonly type: {
            readonly description: "Content-type(s) with which this condition works";
            readonly oneOf: readonly [{
                readonly type: "string";
            }, {
                readonly type: "array";
                readonly items: {
                    readonly type: "string";
                };
            }];
        };
        readonly description: {
            readonly description: "Human description of the condition for UI etc.";
            readonly type: "string";
            readonly examples: readonly ["has a valid signature"];
        };
        readonly uischema: {
            readonly description: "UISchema for the params";
            readonly $comment: "Not sure this is a good idea";
            readonly type: "object";
        };
        readonly params: {
            readonly description: "Input parameters for the condition";
            readonly $ref: "https://json-schema.org/draft/2019-09/schema";
        };
        readonly pointers: {
            readonly description: "A map for applying params to schema.";
            readonly type: "object";
            readonly $comment: "Is there a way to specify the keys are JSON pointers?";
            readonly additionalProperties: {
                readonly type: "object";
                readonly required: readonly ["name", "iskey"];
                readonly properties: {
                    readonly name: {
                        readonly description: "Name of the input to apply at this path.";
                        readonly type: "string";
                    };
                    readonly iskey: {
                        readonly description: "Wether to replace the key or the value.";
                        readonly type: "boolean";
                    };
                };
            };
            readonly examples: readonly [{
                readonly '/a/b/c': {
                    readonly name: "s1";
                    readonly iskey: true;
                };
                readonly '/d/e': {
                    readonly name: "s2";
                    readonly iskey: false;
                };
            }];
        };
    };
    readonly required: readonly ["name", "type", "description"];
};
export = schema;
