declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/rules/configured.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Representation of a constructed OADA rule for rules engine";
    readonly properties: {
        readonly enabled: {
            readonly description: "Wether this rule should be active";
            readonly type: "boolean";
            readonly default: true;
        };
        readonly services: {
            readonly description: "Array of the names of the services involved in this rule";
            readonly $comment: "Should this be here?";
            readonly type: "array";
            readonly items: {
                readonly type: "string";
            };
            readonly uniqueItems: true;
        };
        readonly type: {
            readonly description: "Content-type this rule applies to";
            readonly type: "string";
        };
        readonly on: {
            readonly $comment: "Where should this definiton live?";
            readonly description: "Whether to trigger on new item, changed item, etc.";
            readonly oneOf: readonly [{
                readonly description: "Trigger on a new item being added";
                readonly enum: readonly ["new"];
            }, {
                readonly description: "Trigger on any change to an item";
                readonly enum: readonly ["change"];
            }];
            readonly default: "new";
        };
        readonly path: {
            readonly description: "The path to an OADA list to which to apply this rule";
            readonly $ref: "../../oada.schema.json#/definitions/path";
        };
        readonly conditions: {
            readonly description: "List of conditions involved in this rule";
            readonly additionalProperties: {
                readonly description: "Particular condition involved in this rule";
                readonly type: "object";
                readonly properties: {
                    readonly condition: {
                        readonly description: "A link to the condition document";
                        readonly $ref: "../../oada/link/v1.schema.json#/definitions/versioned";
                    };
                    readonly options: {
                        readonly description: "Parameter values for this condition";
                        readonly type: "object";
                    };
                };
                readonly required: readonly ["condition"];
            };
        };
        readonly actions: {
            readonly description: "List of actions involved in this rule";
            readonly additionalProperties: {
                readonly description: "Particular action involved in this rule";
                readonly type: "object";
                readonly properties: {
                    readonly action: {
                        readonly description: "A link to the action document";
                        readonly $ref: "../../oada/link/v1.schema.json#/definitions/versioned";
                    };
                    readonly options: {
                        readonly description: "Parameter values for this action";
                        readonly type: "object";
                    };
                };
                readonly required: readonly ["action"];
            };
        };
    };
    readonly required: readonly ["type", "path", "conditions", "actions"];
    readonly examples: readonly [{
        readonly type: "application/json";
        readonly enabled: true;
        readonly path: "/bookmarks/foo";
        readonly on: "new";
        readonly services: readonly ["test-service"];
        readonly actions: {
            readonly 'test-action': {
                readonly action: {
                    readonly _id: "resources/foo";
                    readonly _rev: 1;
                };
                readonly options: {
                    readonly foo: 1;
                    readonly bar: "a";
                };
            };
        };
        readonly conditions: {};
    }];
};
export = schema;
