declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/service/abalonemail/config/email.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Abalonemail email config format for @oada/job job";
    readonly type: "object";
    readonly definitions: {
        readonly email: {
            readonly $comment: "TODO: Allow emails like: 'John Doe <john@example.org>'";
            readonly description: "Object for email and associated person's name";
            readonly oneOf: readonly [{
                readonly type: "string";
                readonly format: "email";
            }, {
                readonly type: "object";
                readonly properties: {
                    readonly email: {
                        readonly type: "string";
                        readonly format: "email";
                    };
                    readonly name: {
                        readonly type: "string";
                    };
                };
                readonly required: readonly ["email"];
            }];
        };
    };
    readonly properties: {
        readonly multiple: {
            readonly description: "If separate emails to each `to` (true) or if one email to all of `to` (false)";
            readonly type: "boolean";
        };
        readonly from: {
            readonly $ref: "#/definitions/email";
        };
        readonly to: {
            readonly oneOf: readonly [{
                readonly $ref: "#/definitions/email";
            }, {
                readonly type: "array";
                readonly items: {
                    readonly $ref: "#/definitions/email";
                };
            }];
        };
        readonly replyTo: {
            readonly $ref: "#/definitions/email";
        };
        readonly subject: {
            readonly type: "string";
            readonly minLength: 1;
        };
        readonly text: {
            readonly type: "string";
            readonly minLength: 1;
        };
        readonly html: {
            readonly type: "string";
            readonly minLength: 1;
        };
        readonly templateData: {
            readonly type: "object";
            readonly description: "Data to use when filling out email template";
        };
        readonly attachments: {
            readonly type: "array";
            readonly items: {
                readonly type: "object";
                readonly properties: {
                    readonly content: {
                        readonly oneOf: readonly [{
                            readonly description: "Base 64 encoded attachment content";
                            readonly type: "string";
                            readonly minLength: 1;
                        }, {
                            readonly description: "Link to OADA resource to use as content";
                            readonly $ref: "../../../../oada.schema.json#/definitions/link";
                        }];
                    };
                    readonly filename: {
                        readonly type: "string";
                        readonly minLength: 1;
                    };
                    readonly type: {
                        readonly type: "string";
                        readonly minLength: 1;
                    };
                    readonly disposition: {
                        readonly enum: readonly ["inline", "attachment"];
                        readonly default: "attachment";
                    };
                    readonly content_id: {
                        readonly type: "string";
                    };
                };
                readonly required: readonly ["content", "filename"];
                readonly if: {
                    readonly type: "object";
                    readonly properties: {
                        readonly disposition: {
                            readonly const: "inline";
                        };
                    };
                    readonly required: readonly ["disposition"];
                };
                readonly then: {
                    readonly type: "object";
                    readonly required: readonly ["content_id"];
                };
            };
        };
    };
    readonly required: readonly ["from", "to"];
    readonly examples: readonly [{
        readonly multiple: false;
        readonly from: "john@example.com";
        readonly to: {
            readonly name: "Mary Lou";
            readonly email: "donuts@example.org";
        };
        readonly subject: "Test mail";
        readonly text: "Test!";
        readonly html: "<h1>Test!</h1>";
        readonly attachments: readonly [{
            readonly content: "RXhhbXBsZSBkYXRh";
            readonly filename: "test.dat";
            readonly type: "plain/text";
        }, {
            readonly content: {
                readonly _id: "resources/abc123";
            };
            readonly filename: "file.pdf";
            readonly type: "application/pdf";
        }];
    }];
};
export = schema;
