declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/service/abalonemail/email.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Extension @oada/jobs job queue format for Abalonemail";
    readonly type: "object";
    readonly allOf: readonly [{
        readonly $ref: "../../../oada/service/job.schema.json";
    }];
    readonly properties: {
        readonly service: {
            readonly description: "Service name";
            readonly const: "abalonemail";
        };
        readonly type: {
            readonly description: "Email job type";
            readonly const: "email";
        };
        readonly config: {
            readonly description: "Job spceific configuration object";
            readonly $ref: "config/email.schema.json";
        };
        readonly result: {
            readonly description: "Final result of job";
        };
    };
    readonly required: readonly ["config"];
    readonly examples: readonly [{
        readonly _id: "resources/123";
        readonly _type: "application/vnd.trellis.service.job.1+json";
        readonly _meta: {
            readonly _id: "resources/123/_meta";
            readonly _rev: 3;
        };
        readonly _rev: 3;
        readonly service: "abalonemail";
        readonly type: "email";
        readonly config: {
            readonly multiple: false;
            readonly from: "john@example.com";
            readonly to: {
                readonly name: "Mary Lou";
                readonly email: "donuts@example.org";
            };
            readonly subject: "Test mail";
            readonly text: "Test!";
            readonly html: "<h1>Test!</h1>";
            readonly attachments: readonly [{
                readonly content: "RXhhbXBsZSBkYXRh";
                readonly filename: "test.dat";
                readonly type: "plain/text";
            }, {
                readonly content: {
                    readonly _id: "resources/abc123";
                };
                readonly filename: "file.pdf";
                readonly type: "application/pdf";
            }];
        };
        readonly status: "pending";
        readonly updates: {
            readonly '1bF4ELuQwqU3CjDOsn2NF0d7Deu': {
                readonly status: "started";
                readonly time: "2018-11-14T20:20:39+00:00";
                readonly information: "started";
            };
            readonly '1bF4GjXWJvj6FJEXCiAj8DatQTD': {
                readonly status: "sending";
                readonly time: "2018-11-13T20:20:39+00:00";
                readonly information: "sending email";
            };
        };
    }];
};
export = schema;
