"use strict";
const schema = {
    $id: 'https://formats.openag.io/trellis/service/fl-pusher/sync.schema.json',
    $schema: 'http://json-schema.org/draft-07/schema#',
    description: 'Extension of @oada/job format for fl-pusher',
    type: 'object',
    allOf: [{ $ref: '../../../oada/service/job.schema.json' }],
    properties: {
        service: {
            description: 'Service Name',
            const: 'fl-pusher',
        },
        type: {
            description: 'Foodlogiq Synchronization Job',
            const: 'sync',
        },
        config: {
            description: 'Job specific configuration object',
            type: 'object',
            required: ['resourceId', 'businessId'],
            properties: {
                resourceId: {
                    description: 'id for virtualized pdf',
                    type: 'string',
                },
                businessId: {
                    description: 'The foodlogiq business ID where the document is stored',
                    type: 'string',
                },
                communityIds: {
                    description: 'The foodlogiq community IDs the document is to be shared with',
                    type: 'array',
                    items: { type: 'string' },
                },
            },
        },
        result: {
            description: 'Final result of job',
        },
    },
    examples: [
        {
            _id: 'resources/123',
            _type: 'application/vnd.trellis.service.job.1+json',
            _meta: {
                _id: 'resources/123/_meta',
                _rev: 3,
            },
            _rev: 3,
            service: 'fl-pusher',
            type: 'sync',
            config: {
                resourceId: 'resources/oivnoseklnvaoeij329814ng',
                businessId: '123456789012345678901234',
                communityIds: [
                    '223456789012345678901234',
                    '323456789012345678901234',
                    '423456789012345678901234',
                ],
            },
            status: 'pending',
            updates: {
                aoihngklsdmfjoavin2398havj: {
                    status: 'started',
                    time: '2019-10-20T20:07:21+00:00',
                    information: 'started',
                },
            },
        },
    ],
};
module.exports = schema;
//# sourceMappingURL=sync.schema.cjs.map