declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/service/fl-pusher/sync.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "Extension of @oada/job format for fl-pusher";
    readonly type: "object";
    readonly allOf: readonly [{
        readonly $ref: "../../../oada/service/job.schema.json";
    }];
    readonly properties: {
        readonly service: {
            readonly description: "Service Name";
            readonly const: "fl-pusher";
        };
        readonly type: {
            readonly description: "Foodlogiq Synchronization Job";
            readonly const: "sync";
        };
        readonly config: {
            readonly description: "Job specific configuration object";
            readonly type: "object";
            readonly required: readonly ["resourceId", "businessId"];
            readonly properties: {
                readonly resourceId: {
                    readonly description: "id for virtualized pdf";
                    readonly type: "string";
                };
                readonly businessId: {
                    readonly description: "The foodlogiq business ID where the document is stored";
                    readonly type: "string";
                };
                readonly communityIds: {
                    readonly description: "The foodlogiq community IDs the document is to be shared with";
                    readonly type: "array";
                    readonly items: {
                        readonly type: "string";
                    };
                };
            };
        };
        readonly result: {
            readonly description: "Final result of job";
        };
    };
    readonly examples: readonly [{
        readonly _id: "resources/123";
        readonly _type: "application/vnd.trellis.service.job.1+json";
        readonly _meta: {
            readonly _id: "resources/123/_meta";
            readonly _rev: 3;
        };
        readonly _rev: 3;
        readonly service: "fl-pusher";
        readonly type: "sync";
        readonly config: {
            readonly resourceId: "resources/oivnoseklnvaoeij329814ng";
            readonly businessId: "123456789012345678901234";
            readonly communityIds: readonly ["223456789012345678901234", "323456789012345678901234", "423456789012345678901234"];
        };
        readonly status: "pending";
        readonly updates: {
            readonly aoihngklsdmfjoavin2398havj: {
                readonly status: "started";
                readonly time: "2019-10-20T20:07:21+00:00";
                readonly information: "started";
            };
        };
    }];
};
export = schema;
