"use strict";
const schema = {
    $id: 'https://formats.openag.io/trellis/service/ift-pusher/sync.schema.json',
    $schema: 'http://json-schema.org/draft-07/schema#',
    description: 'Extension of @oada/job format for ift-pusher',
    type: 'object',
    allOf: [{ $ref: '../../../oada/service/job.schema.json' }],
    properties: {
        service: {
            description: 'Service Name',
            const: 'ift-pusher',
        },
        type: {
            description: 'IFT Synchronization Job',
            const: 'sync',
        },
        config: {
            description: 'Job specific configuration object',
            type: 'object',
            required: ['resourceId'],
            properties: {
                resourceId: {
                    description: 'id for virtualized pdf',
                    type: 'string',
                },
            },
        },
        result: {
            description: 'Final result of job',
        },
    },
    examples: [
        {
            _id: 'resources/123',
            _type: 'application/vnd.trellis.service.job.1+json',
            _meta: {
                _id: 'resources/123/_meta',
                _rev: 3,
            },
            _rev: 3,
            service: 'ift-pusher',
            type: 'sync',
            config: {
                resourceId: 'resources/oivnoseklnvaoeij329814ng',
            },
            status: 'pending',
            updates: {
                aoihngklsdmfjoavin2398havj: {
                    status: 'started',
                    time: '2019-10-20T20:07:21+00:00',
                    information: 'started',
                },
            },
        },
    ],
};
module.exports = schema;
//# sourceMappingURL=sync.schema.cjs.map