import { type ArrayValues, type Get, type IfNever, type MergeDeep, type Paths, type Replace, type TupleToUnion } from 'type-fest';
export declare function rfc<N extends number, S extends string | number | never = never>(rfcNumber: N, section?: S): IfNever<S, `https://datatracker.ietf.org/doc/html/rfc${N}`, `https://datatracker.ietf.org/doc/html/rfc${N}#section-${S}`>;
export declare function iana<P extends string, A extends string>(protocol: P, assignment: A): {
    csv: `https://www.iana.org/assignments/${P}/${A}.csv`;
    uri: `https://www.iana.org/assignments/${P}/${P}.xhtml#${A}`;
};
export declare function importSchema(file: string): Promise<import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8BaseSchema<"allowed", import("jsonschema8").JSONSchema8Type>> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8TypeSchema<"allowed", import("jsonschema8").JSONSchema8Type>> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8NullSchema<"allowed">> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8NumericSchema<"allowed">> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8StringSchema<"allowed">> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8ArraySchema<"allowed">> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8ObjectSchema<"allowed">> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8EnumSchema<"allowed">> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8ConstSchema<"allowed">> | import("type-fest/source/readonly-deep").ReadonlyObjectDeep<import("jsonschema8").JSONSchema8TypeArraySchema<"allowed">>>;
declare const columnDefaults: readonly ["value", "description"];
export declare const columns: {
    readonly jose: {
        readonly 'web-key-parameters': readonly ["value", "description", "kty"];
    };
};
type Columns = typeof columns;
type Column<P extends string, A extends string> = P extends keyof Columns ? A extends keyof Columns[P] ? Columns[P][A] : typeof columnDefaults : typeof columnDefaults;
export type Row<P extends string, A extends string> = Record<TupleToUnion<Column<P, A>> | 'reference', string>;
export declare function ianaAssignments<P extends string, A extends string>(protocol: P, assignment: A): Promise<AsyncIterable<{
    record: Row<P, A>;
    info: Record<string, unknown>;
}> & {
    map<R>(f: (record: Row<P, A>) => R): Promise<R[]>;
    uri: `https://www.iana.org/assignments/${P}/${P}.xhtml#${A}`;
}>;
declare const tsKey = "tsType";
export declare function typescript(strings: TemplateStringsArray, ...values: ReadonlyArray<string | {
    [tsKey]: string;
} | {
    enum: readonly unknown[];
}>): {
    tsType: string;
};
export type JSONPointers<T> = Paths<T> extends string ? `/${Replace<Paths<T>, '.', '/', {
    all: true;
}>}` : never;
export type ToPath<T extends `/${string}`> = Replace<Replace<T, '/', ''>, '/', '.', {
    all: true;
}>;
export declare function $ref<S extends {
    $id?: string;
    pattern?: string;
}, P extends JSONPointers<S> = never>(schema: S, p?: P): $Ref<S, P> & IfNever<P, S, Get<S, Replace<Replace<P, "/", "", {}>, "/", ".", {
    all: true;
}>, {
    strict: false;
}>>;
export declare function each<A extends readonly [...unknown[]], E extends ArrayValues<A>, R>(a: A, fun: <C extends E>(element: C) => R): any;
export declare function merge<A, B>(a: A, b: B): MergeDeep<A, B>;
export declare function properties<A, B>(a: A, b: B): {
    properties: MergeDeep<A, B>;
};
export {};
