/**
 * @license
 * Copyright 2022 Open Ag Data Alliance
 *
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */

import type { JSONSchema8 as Schema } from 'jsonschema8';

const schema = {
  $id: 'https://formats.openag.io/oada/as-harvested/v1.schema.json',
  $schema: 'http://json-schema.org/draft-07/schema#',
  description:
    'The "as-harvested" key holds the original data logged during harvest.  This can be collections of time-series harvest data or data that is already geospatially referenced.  A typical "yield map" exported from an FMIS system would go here.  Think of this like the "raw" data that is used to generate tiled maps.',
  properties: {
    'yield-moisture-dataset': {
      description:
        'A link in OADA has at least an _id key and links one resource to another.',
      properties: {
        _id: {
          description: '_id identifies a resource in the OADA API.',
          type: 'string',
        },
      },
      required: ['_id'],
      type: 'object',
    },
    '_id': {
      description: '_id identifies a resource in the OADA API.',
      type: 'string',
    },
    '_rev': {
      description:
        '_rev is the revision string for a resource in the OADA API.',
      type: 'integer',
    },
    '_meta': {
      description: '_meta is a link to the meta document for a resources.',
      properties: {
        _id: {
          description: '_id identifies a resource in the OADA API.',
          type: 'string',
        },
        _rev: {
          description:
            '_rev is the revision string for a resource in the OADA API.',
          type: 'integer',
        },
      },
      required: ['_id', '_rev'],
      type: 'object',
    },
    '_type': {
      enum: ['application/vnd.oada.as-harvested.1+json'],
    },
  },
  additionalProperties: true,
  required: ['_type'],
  type: 'object',
  examples: [
    {
      '_id': 'resources/kfj20ikejldss',
      '_rev': 9,
      '_type': 'application/vnd.oada.as-harvested.1+json',
      'yield-moisture-dataset': {
        _id: 'resources/02ijfkl3k20ij3fsf',
      },
    },
  ],
} as const satisfies Schema;
export = schema;
